@@ -6,7 +6,7 @@ import time
 class TestListen:
     def test_listen_data(self):
         scheduler = QueueScheduler()
-        scheduler.start_queue_scheduler()
+        scheduler.start()
         scheduler.update_listen_data("key_1", "value_1")
         time.sleep(0.001)
         scheduler.update_listen_data("key_1", "value_2")
@@ -15,6 +15,6 @@ class TestListen:
         time.sleep(0.001)
         scheduler.update_listen_data("key_1", "value_4")
         time.sleep(0.001)
-        scheduler.stop_queue_scheduler()
+        scheduler.stop()
         print(scheduler.get_listen_datas())
         print(scheduler.get_listen_data("key_1"))
